``pyramid_tm``
==============

.. image:: https://travis-ci.org/Pylons/pyramid_tm.png?branch=master
        :target: https://travis-ci.org/Pylons/pyramid_tm

.. image:: https://readthedocs.org/projects/pyramid_tm/badge/?version=latest
        :target: http://docs.pylonsproject.org/projects/pyramid_tm/en/latest/
        :alt: Documentation Status

``pyramid_tm`` is a package which allows Pyramid requests to join
the active transaction as provided by the `transaction
<http://pypi.python.org/pypi/transaction>`_ package.

See `http://docs.pylonsproject.org/projects/pyramid_tm/en/latest/
<http://docs.pylonsproject.org/projects/pyramid_tm/en/latest/>`_ 
or ``docs/index.rst`` in this distribution for detailed
documentation.
